@@ -32,11 +32,13 @@ def convertToDateTime(timeArg):
     the dynamicserialize types like Date and Timestamp. Raises TypeError
     if no conversion can be performed.
 
-    :param timeArg: a python object representing a date and time. Supported
-        types include datetime, struct_time, float, int, long and the
-        dynamicserialize types Date and Timestamp.
+    Args:
+            timeArg: a python object representing a date and time. Supported
+            types include datetime, struct_time, float, int, long and the
+            dynamicserialize types Date and Timestamp.
 
-    :returns: A datetime that represents the same date/time as the passed in object.
+    Returns:
+        A datetime that represents the same date/time as the passed in object.
     """
     if isinstance(timeArg, datetime.datetime):
         return timeArg
@@ -71,10 +73,12 @@ def constructTimeRange(*args):
     Builds a python dynamicserialize TimeRange object from the given
     arguments.
 
-    :param args*: must be a TimeRange or a pair of objects that can be
-         converted to a datetime via convertToDateTime().
+    Args:
+            args*: must be a TimeRange or a pair of objects that can be
+                   converted to a datetime via convertToDateTime().
 
-    :returns: A TimeRange.
+    Returns:
+        A TimeRange.
     """
 
     if len(args) == 1 and isinstance(args[0], TimeRange):
