@@ -23,8 +23,8 @@
 #    Jun 01, 2016    5587          tgurney        Add new signatures for
 #                                                 getRequiredIdentifiers() and
 #                                                 getOptionalIdentifiers()
-#    10/07/16         ----         mjames@ucar    Added getForecastRun
-#
+#    Oct 07, 2016    ----          mjames@ucar    Added getForecastRun
+#    Oct 18, 2016    5916          bsteffen       Add setLazyLoadGridLatLon
 #
 #
 
@@ -34,8 +34,10 @@ import subprocess
 import warnings
 
 THRIFT_HOST = "edex"
+
 USING_NATIVE_THRIFT = False
 
+
 if 'jep' in sys.modules:
     # intentionally do not catch if this fails to import, we want it to
     # be obvious that something is configured wrong when running from within
@@ -63,10 +65,13 @@ def getAvailableTimes(request, refTimeOnly=False):
     """
     Get the times of available data to the request.
 
-    :param request: the IDataRequest to get data for
-    :param refTimeOnly: optional, use True if only unique refTimes should be returned (without a forecastHr)
+    Args:
+            request: the IDataRequest to get data for
+            refTimeOnly: optional, use True if only unique refTimes should be
+                          returned (without a forecastHr)
 
-    :returns: a list of DataTimes
+    Returns:
+            a list of DataTimes
     """
     return router.getAvailableTimes(request, refTimeOnly)
 
@@ -77,10 +82,13 @@ def getGridData(request, times=[]):
     combination of parameter, level, and dataTime will be returned as a
     separate IGridData.
 
-    :param request: the IDataRequest to get data for
-    :param times: a list of DataTimes, a TimeRange, or None if the data is time agnostic
+    Args:
+            request: the IDataRequest to get data for
+            times: a list of DataTimes, a TimeRange, or None if the data is time
+                    agnostic
 
-    :returns: a list of IGridData
+    Returns:
+            a list of IGridData
     """
     return router.getGridData(request, times)
 
@@ -91,10 +99,13 @@ def getGeometryData(request, times=[]):
     Each combination of geometry, level, and dataTime will be returned as a
     separate IGeometryData.
 
-    :param request: the IDataRequest to get data for
-    :param times: a list of DataTimes, a TimeRange, or None if the data is time agnostic
+    Args:
+            request: the IDataRequest to get data for
+            times: a list of DataTimes, a TimeRange, or None if the data is time
+                    agnostic
 
-    :returns: a list of IGeometryData
+    Returns:
+            a list of IGeometryData
     """
     return router.getGeometryData(request, times)
 
@@ -104,9 +115,11 @@ def getAvailableLocationNames(request):
     Gets the available location names that match the request without actually
     requesting the data.
 
-    :param request: the request to find matching location names for
+    Args:
+            request: the request to find matching location names for
 
-    :returns: a list of strings of available location names.
+    Returns:
+            a list of strings of available location names.
     """
     return router.getAvailableLocationNames(request)
 
@@ -116,9 +129,11 @@ def getAvailableParameters(request):
     Gets the available parameters names that match the request without actually
     requesting the data.
 
-    :param request: the request to find matching parameter names for
+    Args:
+            request: the request to find matching parameter names for
 
-    :returns: a list of strings of available parameter names.
+    Returns:
+            a list of strings of available parameter names.
     """
     return router.getAvailableParameters(request)
 
@@ -128,9 +143,11 @@ def getAvailableLevels(request):
     Gets the available levels that match the request without actually
     requesting the data.
 
-    :param request: the request to find matching levels for
+    Args:
+            request: the request to find matching levels for
 
-    :returns: a list of strings of available levels.
+    Returns:
+            a list of strings of available levels.
     """
     return router.getAvailableLevels(request)
 
@@ -140,9 +157,11 @@ def getRequiredIdentifiers(request):
     Gets the required identifiers for this request.  These identifiers
     must be set on a request for the request of this datatype to succeed.
 
-    :param request: the request to find required identifiers
+    Args:
+            request: the request to find required identifiers for
 
-    :returns: a list of strings of required identifiers
+    Returns:
+            a list of strings of required identifiers
     """
     if str(request) == request:
         warnings.warn("Use getRequiredIdentifiers(IDataRequest) instead",
@@ -154,9 +173,11 @@ def getOptionalIdentifiers(request):
     """
     Gets the optional identifiers for this request.
 
-    :param request: the reuqest to find optional identifiers for
+    Args:
+            request: the request to find optional identifiers for
 
-    :returns: a list of strings of optional identifiers
+    Returns:
+            a list of strings of optional identifiers
     """
     if str(request) == request:
         warnings.warn("Use getOptionalIdentifiers(IDataRequest) instead",
@@ -168,26 +189,30 @@ def getIdentifierValues(request, identifierKey):
     """
     Gets the allowed values for a particular identifier on this datatype.
 
-    :param request: the request to find identifier values for
-    :praram identifierKey: the identifier to find values for
+    Args:
+            request: the request to find identifier values for
+            identifierKey: the identifier to find values for
 
-    :returns: a list of strings of allowed values for the specified identifier
+    Returns:
+            a list of strings of allowed values for the specified identifier
     """
     return router.getIdentifierValues(request, identifierKey)
 
 def newDataRequest(datatype=None, **kwargs):
-    """
+    """"
     Creates a new instance of IDataRequest suitable for the runtime environment.
     All args are optional and exist solely for convenience.
 
-    :param datatype: the datatype to create a request for
-    :param parameters: a list of parameters to set on the request
-    :param levels: a list of levels to set on the request
-    :param locationNames: a list of locationNames to set on the request
-    :param envelope: an envelope to limit the request
-    :param kwargs: any leftover kwargs will be set as identifiers
+    Args:
+            datatype: the datatype to create a request for
+            parameters: a list of parameters to set on the request
+            levels: a list of levels to set on the request
+            locationNames: a list of locationNames to set on the request
+            envelope: an envelope to limit the request
+            **kwargs: any leftover kwargs will be set as identifiers
 
-    :returns: a new IDataRequest
+    Returns:
+            a new IDataRequest
     """
     return router.newDataRequest(datatype, **kwargs)
 
@@ -195,7 +220,8 @@ def getSupportedDatatypes():
     """
     Gets the datatypes that are supported by the framework
 
-    :returns: a list of strings of supported datatypes
+    Returns:
+            a list of strings of supported datatypes
     """
     return router.getSupportedDatatypes()
 
@@ -206,7 +232,8 @@ def changeEDEXHost(newHostName):
     works if using the native Python client implementation, otherwise, this
     method will throw a TypeError.
 
-    :param newHostHame: the EDEX host to connect to
+    Args:
+            newHostHame: the EDEX host to connect to
     """
     if USING_NATIVE_THRIFT:
         global THRIFT_HOST
@@ -215,3 +242,26 @@ def changeEDEXHost(newHostName):
         router = ThriftClientRouter.ThriftClientRouter(THRIFT_HOST)
     else:
         raise TypeError("Cannot call changeEDEXHost when using JepRouter.")
+
+def setLazyLoadGridLatLon(lazyLoadGridLatLon):
+    """
+    Provide a hint to the Data Access Framework indicating whether to load the
+    lat/lon data for a grid immediately or wait until it is needed. This is
+    provided as a performance tuning hint and should not affect the way the
+    Data Access Framework is used. Depending on the internal implementation of
+    the Data Access Framework this hint might be ignored. Examples of when this
+    should be set to True are when the lat/lon information is not used or when
+    it is used only if certain conditions within the data are met. It could be
+    set to False if it is guaranteed that all lat/lon information is needed and
+    it would be better to get any performance overhead for generating the
+    lat/lon data out of the way during the initial request.
+
+
+    Args:
+            lazyLoadGridLatLon: Boolean value indicating whether to lazy load.
+    """
+    try:
+        router.setLazyLoadGridLatLon(lazyLoadGridLatLon)
+    except AttributeError:
+        # The router is not required to support this capability.
+        pass
