@@ -25,18 +25,24 @@ from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.level import Lev
 
 
 def getSounding(modelName, weatherElements, levels, samplePoint, refTime=None, timeRange=None):
-    """
+    """"
     Performs a series of Data Access Framework requests to retrieve a sounding object
     based on the specified request parameters.
 
-    :param modelName: the grid model datasetid to use as the basis of the sounding.
-    :param weatherElements: a list of parameters to return in the sounding.
-    :param levels: a list of levels to sample the given weather elements at
-    :param samplePoint: a lat/lon pair to perform the sampling of data at.
-    :param refTime: (optional) the grid model reference time to use for the sounding. If not specified, the latest ref time in the system will be used.
-    :param timeRange: (optional) a TimeRange to specify which forecast hours to use. If not specified, will default to all forecast hours.
+    Args:
+            modelName: the grid model datasetid to use as the basis of the sounding.
+            weatherElements: a list of parameters to return in the sounding.
+            levels: a list of levels to sample the given weather elements at
+            samplePoint: a lat/lon pair to perform the sampling of data at.
+            refTime: (optional) the grid model reference time to use for the sounding.
+                     If not specified, the latest ref time in the system will be used.
+            timeRange: (optional) a TimeRange to specify which forecast hours to use.
+                     If not specified, will default to all forecast hours.
 
-    :returns: A _SoundingCube instance, which acts a 3-tiered dictionary, keyed by DataTime, then by level and finally by weather element. If no data is available for the given request parameters, None is returned.
+    Returns:
+            A _SoundingCube instance, which acts a 3-tiered dictionary, keyed
+            by DataTime, then by level and finally by weather element. If no
+            data is available for the given request parameters, None is returned.
     """
 
     (locationNames, parameters, levels, envelope, refTime, timeRange) = \
@@ -64,7 +70,8 @@ def setEDEXHost(host):
     """
     Changes the EDEX host the Data Access Framework is communicating with.
 
-    :param host: the EDEX host to connect to
+    Args:
+            host: the EDEX host to connect to
     """
 
     if host:
@@ -150,7 +157,8 @@ class _SoundingCube(object):
         """
         Returns the valid times for this sounding.
 
-        :returns: A list containing the valid DataTimes for this sounding in order.
+        Returns:
+            A list containing the valid DataTimes for this sounding in order.
         """
         return self._sortedTimes
 
@@ -188,7 +196,8 @@ class _SoundingTimeLayer(object):
         """
         Returns the DataTime for this sounding cube layer.
 
-        :returns: The DataTime for this sounding layer.
+        Returns:
+            The DataTime for this sounding layer.
         """
         return self._dataTime
 
@@ -196,7 +205,9 @@ class _SoundingTimeLayer(object):
         """
         Returns the valid levels for this sounding.
 
-        :returns: A list containing the valid levels for this sounding in order of closest to surface to highest from surface.
+        Returns:
+            A list containing the valid levels for this sounding in order of
+            closest to surface to highest from surface.
         """
         sortedLevels = [Level(level) for level in list(self._dataDict.keys())]
         sortedLevels.sort()
@@ -231,7 +242,8 @@ class _SoundingTimeAndLevelLayer(object):
         """
         Returns the level for this sounding cube layer.
 
-        :returns: The level for this sounding layer.
+        Returns:
+            The level for this sounding layer.
         """
         return self._level
 
@@ -239,7 +251,8 @@ class _SoundingTimeAndLevelLayer(object):
         """
         Returns the valid parameters for this sounding.
 
-        :returns: A list containing the valid parameter names.
+        Returns:
+            A list containing the valid parameter names.
         """
         return list(self._parameters.keys())
 
@@ -247,6 +260,7 @@ class _SoundingTimeAndLevelLayer(object):
         """
         Returns the DataTime for this sounding cube layer.
 
-        :returns: The DataTime for this sounding layer.
+        Returns:
+            The DataTime for this sounding layer.
         """
         return self._time
