@@ -21,7 +21,9 @@
 #    06/01/16        5587          tgurney        Add new signatures for
 #                                                 getRequiredIdentifiers() and
 #                                                 getOptionalIdentifiers()
-#    11/10/16        5900          bsteffen       Correct grid shape
+#    08/01/16        2416          tgurney        Add getNotificationFilter()
+#    10/13/16        5916          bsteffen       Correct grid shape, allow lazy grid lat/lon
+#    10/26/16        5919          njensen        Speed up geometry creation in getGeometryData()
 #
 
 
@@ -33,22 +35,53 @@ from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import G
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetAvailableTimesRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetGeometryDataRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetGridDataRequest
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetGridLatLonRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetAvailableParametersRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetAvailableLevelsRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetRequiredIdentifiersRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetOptionalIdentifiersRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetIdentifierValuesRequest
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetSupportedDatatypesRequest
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataaccess.request import GetNotificationFilterRequest
 
 from awips import ThriftClient
 from awips.dataaccess import PyGeometryData
 from awips.dataaccess import PyGridData
 
 
+class LazyGridLatLon(object):
+
+    def __init__(self, client, nx, ny, envelope, crsWkt):
+        self._latLonGrid = None
+        self._client = client
+        self._request = GetGridLatLonRequest()
+        self._request.setNx(nx)
+        self._request.setNy(ny)
+        self._request.setEnvelope(envelope)
+        self._request.setCrsWkt(crsWkt)
+
+    def __call__(self):
+        # Its important that the data is cached internally so that if multiple
+        # GridData are sharing the same delegate then they can also share a
+        # single request for the LatLon information.
+        if self._latLonGrid is None:
+            response = self._client.sendRequest(self._request)
+            nx = response.getNx()
+            ny = response.getNy()
+            latData = numpy.reshape(numpy.array(response.getLats()), (ny, nx))
+            lonData = numpy.reshape(numpy.array(response.getLons()), (ny, nx))
+            self._latLonGrid = (lonData, latData)
+        return self._latLonGrid
+
+
 class ThriftClientRouter(object):
 
     def __init__(self, host='localhost'):
         self._client = ThriftClient.ThriftClient(host)
+        self._lazyLoadGridLatLon = False
+
+    def setLazyLoadGridLatLon(self, lazyLoadGridLatLon):
+        self._lazyLoadGridLatLon = lazyLoadGridLatLon
 
     def getAvailableTimes(self, request, refTimeOnly):
         timesRequest = GetAvailableTimesRequest()
@@ -59,6 +92,7 @@ class ThriftClientRouter(object):
 
     def getGridData(self, request, times):
         gridDataRequest = GetGridDataRequest()
+        gridDataRequest.setIncludeLatLonData(not self._lazyLoadGridLatLon)
         gridDataRequest.setRequestParameters(request)
         # if we have an iterable times instance, then the user must have asked
         # for grid data with the List of DataTime objects
@@ -76,15 +110,28 @@ class ThriftClientRouter(object):
         for location in locNames:
             nx = response.getSiteNxValues()[location]
             ny = response.getSiteNyValues()[location]
-            latData = numpy.reshape(numpy.array(response.getSiteLatGrids()[location]), (ny, nx))
-            lonData = numpy.reshape(numpy.array(response.getSiteLonGrids()[location]), (ny, nx))
-            locSpecificData[location] = (nx, ny, (lonData, latData))
-
+            if self._lazyLoadGridLatLon:
+                envelope = response.getSiteEnvelopes()[location]
+                crsWkt = response.getSiteCrsWkt()[location]
+                delegate = LazyGridLatLon(
+                    self._client, nx, ny, envelope, crsWkt)
+                locSpecificData[location] = (nx, ny, delegate)
+            else:
+                latData = numpy.reshape(numpy.array(
+                    response.getSiteLatGrids()[location]), (ny, nx))
+                lonData = numpy.reshape(numpy.array(
+                    response.getSiteLonGrids()[location]), (ny, nx))
+                locSpecificData[location] = (nx, ny, (lonData, latData))
         retVal = []
         for gridDataRecord in response.getGridData():
             locationName = gridDataRecord.getLocationName()
             locData = locSpecificData[locationName]
-            retVal.append(PyGridData.PyGridData(gridDataRecord, locData[0], locData[1], locData[2]))
+            if self._lazyLoadGridLatLon:
+                retVal.append(PyGridData.PyGridData(gridDataRecord, locData[
+                              0], locData[1], latLonDelegate=locData[2]))
+            else:
+                retVal.append(PyGridData.PyGridData(
+                    gridDataRecord, locData[0], locData[1], locData[2]))
         return retVal
 
     def getGeometryData(self, request, times):
@@ -102,11 +149,9 @@ class ThriftClientRouter(object):
         response = self._client.sendRequest(geoDataRequest)
         geometries = []
         for wkb in response.getGeometryWKBs():
-            # convert the wkb to a bytearray with only positive values
-            byteArrWKB = bytearray([x % 256 for x in wkb.tolist()])
-            # convert the bytearray to a byte string and load it.
-            geometries.append(shapely.wkb.loads(bytes(byteArrWKB)))
-
+            # the wkb is a numpy.ndarray of dtype int8
+            # convert the bytearray to a byte string and load it
+            geometries.append(shapely.wkb.loads(wkb.tostring()))
 
         retVal = []
         for geoDataRecord in response.getGeoData():
@@ -157,7 +202,7 @@ class ThriftClientRouter(object):
         response = self._client.sendRequest(idValReq)
         return response
 
-    def newDataRequest(self, datatype, parameters=[], levels=[], locationNames = [], envelope=None, **kwargs):
+    def newDataRequest(self, datatype, parameters=[], levels=[], locationNames=[], envelope=None, **kwargs):
         req = DefaultDataRequest()
         if datatype:
             req.setDatatype(datatype)
@@ -177,3 +222,9 @@ class ThriftClientRouter(object):
     def getSupportedDatatypes(self):
         response = self._client.sendRequest(GetSupportedDatatypesRequest())
         return response
+
+    def getNotificationFilter(self, request):
+        notifReq = GetNotificationFilterRequest()
+        notifReq.setRequestParameters(request)
+        response = self._client.sendRequest(notifReq)
+        return response
