@@ -64,6 +64,7 @@
 
 """
 
+from __future__ import print_function
 import hashlib
 import math
 import random
@@ -74,9 +75,11 @@ import threading
 import time
 import types
 import xml.dom.minidom
-from io import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 from functools import reduce
-
 try:
     import _thread
 except ImportError:
@@ -538,7 +541,7 @@ class Connection(object):
 
         if self.__socket is not None:
             frame = '%s\n%s\n%s\x00' % (command,
-                                        reduce(lambda accu, key: accu + ('%s:%s\n' % (key, headers[key])), list(headers.keys()), ''),
+					reduce(lambda accu, key: accu + ('%s:%s\n' % (key, headers[key])), list(headers.keys()), ''),
                                         payload)
             self.__socket.sendall(frame)
             log.debug("Sent frame: type=%s, headers=%r, body=%r" % (command, headers, payload))
@@ -801,13 +804,13 @@ if __name__ == '__main__':
             self.c.start()
 
         def __print_async(self, frame_type, headers, body):
-            #print("\r  \r", end=' ')
+            #print("\r  \r",)
             print(frame_type)
             for header_key in list(headers.keys()):
                 print('%s: %s' % (header_key, headers[header_key]))
             print()
             print(body)
-            print('> ', end=' ')
+	    print('> ', end=' ')
             sys.stdout.flush()
 
         def on_connecting(self, host_and_port):
