@@ -5,6 +5,7 @@ from __future__ import print_function
 from awips.dataaccess import DataAccessLayer as DAL
 
 import baseBufrMosTestCase
+import params
 import unittest
 
 #
@@ -17,6 +18,8 @@ import unittest
 #    01/19/16        4795          mapeters       Initial Creation.
 #    04/11/16        5548          tgurney        Cleanup
 #    04/18/16        5548          tgurney        More cleanup
+#    12/07/16        5981          tgurney        Parameterize
+#    12/20/16        5981          tgurney        Inherit all tests
 #
 #
 
@@ -25,11 +28,6 @@ class BufrMosMrfTestCase(baseBufrMosTestCase.BufrMosTestCase):
     """Test DAF support for bufrmosMRF data"""
 
     datatype = "bufrmosMRF"
+    data_params = "forecastHr", "maxTempDay"
 
-    # Most tests inherited from superclass
-
-    def testGetGeometryData(self):
-        req = DAL.newDataRequest(self.datatype)
-        req.setLocationNames("KOMA")
-        req.setParameters("forecastHr", "maxTempDay")
-        self.runGeometryDataTest(req)
+    # All tests inherited from superclass
