@@ -9,6 +9,7 @@ from awips.dataaccess import DataAccessLayer as DAL
 from awips.ThriftClient import ThriftRequestException
 
 import baseDafTestCase
+import params
 import unittest
 
 #
@@ -25,7 +26,11 @@ import unittest
 #    06/09/16        5574          mapeters       Add advanced query tests, Short parameter test
 #    06/13/16        5574          tgurney        Fix checks for None
 #    06/21/16        5548          tgurney        Skip tests that cause errors
+#    06/30/16        5725          tgurney        Add test for NOT IN
 #    10/06/16        5926          dgilling       Add additional time and location tests.
+#    12/07/16        5981          tgurney        Parameterize
+#    12/20/16        5981          tgurney        Add envelope test
+#    08/16/17        6388          tgurney        Test for duplicate data
 #
 #
 
@@ -34,6 +39,7 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
     """Test DAF support for climate data"""
 
     datatype = 'climate'
+    obsStation = params.OBS_STATION
 
     def testGetAvailableParameters(self):
         req = DAL.newDataRequest(self.datatype)
@@ -86,7 +92,7 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         """
         req = DAL.newDataRequest(self.datatype)
         req.addIdentifier('table', 'public.cli_asos_monthly')
-        req.setLocationNames('KOMA', 'KABR', 'KDMO')
+        req.setLocationNames(self.obsStation, 'KABR', 'KDMO')
         req.setParameters('maxtemp_mon', 'min_sea_press')
         self.runTimesTest(req)
 
@@ -97,7 +103,7 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         """
         req = DAL.newDataRequest(self.datatype)
         req.addIdentifier('table', 'public.cli_asos_daily')
-        req.setLocationNames('KOMA', 'KABR', 'KDMO')
+        req.setLocationNames(self.obsStation, 'KABR', 'KDMO')
         req.setParameters('maxtemp_cal', 'min_press')
         self.runTimesTest(req)
 
@@ -108,7 +114,7 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         """
         req = DAL.newDataRequest(self.datatype)
         req.addIdentifier('table', 'public.cli_mon_season_yr')
-        req.setLocationNames('KOMA', 'KABR', 'KDMO')
+        req.setLocationNames(self.obsStation, 'KABR', 'KDMO')
         req.setParameters('max_temp', 'precip_total')
         self.runTimesTest(req)
 
@@ -119,7 +125,7 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         """
         req = DAL.newDataRequest(self.datatype)
         req.addIdentifier('table', 'public.daily_climate')
-        req.setLocationNames('KOMA', 'KABR', 'KDMO')
+        req.setLocationNames(self.obsStation, 'KABR', 'KDMO')
         req.setParameters('max_temp', 'precip', 'avg_wind_speed')
         self.runTimesTest(req)
 
@@ -137,6 +143,15 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         req.setParameters('maxtemp_mon', 'min_sea_press')
         self.runGeometryDataTest(req)
 
+    def testGetGeometryDataWithEnvelopeThrowsException(self):
+        # Envelope is not used
+        req = DAL.newDataRequest(self.datatype)
+        req.addIdentifier('table', 'public.cli_asos_monthly')
+        req.setParameters('maxtemp_mon', 'min_sea_press')
+        req.setEnvelope(params.ENVELOPE)
+        with self.assertRaises(Exception):
+            data = self.runGeometryDataTest(req)
+
     def testGetGeometryDataForYearAndDayOfYearTable(self):
         """
         Test retrieval of data for a climo table that uses year and
@@ -225,14 +240,14 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         return self.runGeometryDataTest(req)
 
     def testGetDataWithEqualsString(self):
-        geometryData = self._runConstraintTest('station_code', '=', 'KOMA')
+        geometryData = self._runConstraintTest('station_code', '=', self.obsStation)
         for record in geometryData:
-            self.assertEqual(record.getString('station_code'), 'KOMA')
+            self.assertEqual(record.getString('station_code'), self.obsStation)
 
     def testGetDataWithEqualsUnicode(self):
-        geometryData = self._runConstraintTest('station_code', '=', u'KOMA')
+        geometryData = self._runConstraintTest('station_code', '=', unicode(self.obsStation))
         for record in geometryData:
-            self.assertEqual(record.getString('station_code'), 'KOMA')
+            self.assertEqual(record.getString('station_code'), self.obsStation)
 
     def testGetDataWithEqualsInt(self):
         geometryData = self._runConstraintTest('avg_daily_max', '=', 70)
@@ -240,7 +255,7 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
             self.assertEqual(record.getNumber('avg_daily_max'), 70)
 
     def testGetDataWithEqualsLong(self):
-        geometryData = self._runConstraintTest('avg_daily_max', '=', 70L)
+        geometryData = self._runConstraintTest('avg_daily_max', '=', 70)
         for record in geometryData:
             self.assertEqual(record.getNumber('avg_daily_max'), 70)
 
@@ -254,9 +269,9 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         self.assertEqual(len(geometryData), 0)
 
     def testGetDataWithNotEquals(self):
-        geometryData = self._runConstraintTest('station_code', '!=', 'KOMA')
+        geometryData = self._runConstraintTest('station_code', '!=', self.obsStation)
         for record in geometryData:
-            self.assertNotEqual(record.getString('station_code'), 'KOMA')
+            self.assertNotEqual(record.getString('station_code'), self.obsStation)
 
     def testGetDataWithNotEqualsNone(self):
         geometryData = self._runConstraintTest('station_code', '!=', None)
@@ -284,27 +299,33 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
             self.assertLessEqual(record.getNumber('avg_daily_max'), 70)
 
     def testGetDataWithInTuple(self):
-        collection = ('KOMA', 'KABR')
+        collection = (self.obsStation, 'KABR')
         geometryData = self._runConstraintTest('station_code', 'in', collection)
         for record in geometryData:
             self.assertIn(record.getString('station_code'), collection)
 
     def testGetDataWithInList(self):
-        collection = ['KOMA', 'KABR']
+        collection = [self.obsStation, 'KABR']
         geometryData = self._runConstraintTest('station_code', 'in', collection)
         for record in geometryData:
             self.assertIn(record.getString('station_code'), collection)
 
     def testGetDataWithInGenerator(self):
-        collection = ('KOMA', 'KABR')
+        collection = (self.obsStation, 'KABR')
         generator = (item for item in collection)
         geometryData = self._runConstraintTest('station_code', 'in', generator)
         for record in geometryData:
             self.assertIn(record.getString('station_code'), collection)
 
+    def testGetDataWithNotInList(self):
+        collection = ['KORD', 'KABR']
+        geometryData = self._runConstraintTest('station_code', 'not in', collection)
+        for record in geometryData:
+            self.assertNotIn(record.getString('station_code'), collection)
+
     def testGetDataWithInvalidConstraintTypeThrowsException(self):
         with self.assertRaises(ValueError):
-            self._runConstraintTest('station_code', 'junk', 'KOMA')
+            self._runConstraintTest('station_code', 'junk', self.obsStation)
 
     def testGetDataWithInvalidConstraintValueThrowsException(self):
         with self.assertRaises(TypeError):
@@ -394,3 +415,13 @@ class ClimateTestCase(baseDafTestCase.DafTestCase):
         tr = TimeRange(startTime, endTime)
         self.runGeometryDataTestWithTimeRange(req, tr)
 
+    def testNoDuplicateData(self):
+        req = DAL.newDataRequest(self.datatype)
+        req.addIdentifier('table', 'public.cli_asos_monthly')
+        req.setLocationNames('KOMA')
+        req.setParameters('maxtemp_day1')
+        rows = DAL.getGeometryData(req, DAL.getAvailableTimes(req)[0:5])
+        for i in range(len(rows)):
+            for j in range(len(rows)):
+                if i != j:
+                    self.assertNotEqual(rows[i].__dict__, rows[j].__dict__)
