@@ -6,15 +6,15 @@
 # Adapter for com.raytheon.uf.common.message.WsId
 #
 #
-#     SOFTWARE HISTORY
-#
-#    Date            Ticket#       Engineer       Description
-#    ------------    ----------    -----------    --------------------------
-#    09/16/10                      dgilling       Initial Creation.
-#    04/25/12              545     randerso       Repurposed the lockKey field as threadId
-#
+# SOFTWARE HISTORY
 #
+# Date          Ticket#  Engineer  Description
+# ------------- -------- --------- ---------------------------------------------
+# Sep 16, 2010           dgilling  Initial Creation.
+# Apr 25, 2012  545      randerso  Repurposed the lockKey field as threadId
+# Feb 06, 2017  5959     randerso  Removed Java .toString() calls
 #
+##
 
 
 
@@ -24,7 +24,7 @@ ClassAdapter = 'com.raytheon.uf.common.message.WsId'
 
 
 def serialize(context, wsId):
-    context.writeString(wsId.toString())
+    context.writeString(str(wsId))
 
 def deserialize(context):
     wsIdString = context.readString()
